% plot impedance spectrum as Nyquist diagram with zHit verification
% as first step: load data recorded with EISmeter 

f_nyquist = figure('Name', 'Impedance spectrum as Nyquist diagram');
set(f_nyquist,'defaulttextinterpreter','latex');

    ImZ_pos = eisMeter.Zimg_whole_Ohm - eisMeter.Zimg_neg_Ohm; 
    ReZ_pos = eisMeter.Zreal_whole_Ohm - eisMeter.Zreal_neg_Ohm;
    setFreq_pos = eisMeter.ActFreq_Hz;

    ImZ_neg = eisMeter.Zimg_neg_Ohm; 
    ReZ_neg = eisMeter.Zreal_neg_Ohm;
    setFreq_neg = eisMeter.ActFreq_Hz;

    
    ImZ_corr = ImZ_pos(ImZ_pos~=0 & ReZ_pos~=0 & setFreq_pos~=0);
    ReZ_corr = ReZ_pos(ImZ_pos~=0 & ReZ_pos~=0 & setFreq_pos~=0);
    setFreq_corr = setFreq_pos(ImZ_pos~=0 & ReZ_pos~=0 & setFreq_pos~=0);

    ImZ_pos = [ImZ_corr(diff(setFreq_corr) ~= 0), ImZ_corr(end)];
    ReZ_pos = [ReZ_corr(diff(setFreq_corr) ~= 0), ReZ_corr(end)];
    setFreq_pos = [setFreq_corr(diff(setFreq_corr) ~= 0), setFreq_corr(end)];

    ImZ_corr = ImZ_neg(ImZ_neg~=0 & ReZ_neg~=0 & setFreq_neg~=0);
    ReZ_corr = ReZ_neg(ImZ_neg~=0 & ReZ_neg~=0 & setFreq_neg~=0);
    setFreq_corr = setFreq_neg(ImZ_neg~=0 & ReZ_neg~=0 & setFreq_neg~=0);

    if(~isempty(ImZ_corr) && ~isempty(ReZ_corr) && ~isempty(setFreq_pos))
        ImZ_neg = [ImZ_corr(diff(setFreq_corr) ~= 0), ImZ_corr(end)];
        ReZ_neg = [ReZ_corr(diff(setFreq_corr) ~= 0), ReZ_corr(end)];
        setFreq_neg = [setFreq_corr(diff(setFreq_corr) ~= 0), setFreq_corr(end)];
    else
        ImZ_neg = NaN;
        ReZ_neg = NaN;
        setFreq_neg = NaN;
    end;

    % check with zhit
    Amplitude_pos = (sqrt((ReZ_pos).^2 +(ImZ_pos).^2));
    phase_pos = angle(ReZ_pos+1i*ImZ_pos);
    abszhit_pos = zhit(setFreq_pos,Amplitude_pos,phase_pos);

    Amplitude_neg = (sqrt((ReZ_neg).^2 +(ImZ_neg).^2));
    phase_neg = angle(ReZ_neg+1i*ImZ_neg);
    abszhit_neg = zhit(setFreq_neg,Amplitude_neg,phase_neg);

    Amplitude_whole = (sqrt((ReZ_pos + ReZ_neg).^2 +(ImZ_pos + ImZ_neg).^2));
    phase_whole = angle((ReZ_pos + ReZ_neg)+1i*(ImZ_pos + ImZ_neg));
    abszhit_whole = zhit(setFreq_neg,Amplitude_whole,phase_whole);
    
    % plot spectrum of whole cell
    sub_nyquist(1) = subplot(2,1,2);
    hold all;
    plot(ReZ_neg + ReZ_pos,(ImZ_neg + ImZ_pos),'.-');
    plot(abszhit_whole.*cos(phase_whole)',abszhit_whole.*sin(phase_whole)','*-');
    %     
    ReZ_whole = ReZ_neg + ReZ_pos;
    ImZ_whole = ImZ_neg + ImZ_pos;

    if(~isempty(ReZ_whole(abs((abszhit_whole - Amplitude_whole')) < 0.15)))
        plot(ReZ_whole(abs((abszhit_whole - Amplitude_whole')) < 0.15),ImZ_whole(abs((abszhit_whole - Amplitude_whole')) < 0.15),'s');
    end;
    
    legend('meas', 'zHit calc', 'TI pass');
    axis('equal');
    xlabel('Re$\{\underline Z\}$  in m$\Omega$');
    ylabel('Im$\{\underline Z\}$  in m$\Omega$');
    grid on; set(gca,'Ydir','reverse');
    title(' whole cell');
    
    % plot spectrum of negative electrode
    sub_nyquist(2) = subplot(2,1,1);
    plot(ReZ_neg,ImZ_neg,'.-'); hold all;
    plot(abszhit_neg.*cos(phase_neg)',abszhit_neg.*sin(phase_neg)','*-');

    if(~isempty(ReZ_neg(abs((abszhit_neg - Amplitude_neg')) < 0.15)))
        plot(ReZ_neg(abs((abszhit_neg - Amplitude_neg')) < 0.15),ImZ_neg(abs((abszhit_neg - Amplitude_neg')) < 0.15),'s');
    end;
    
    legend('meas', 'zHit calc', 'TI pass');
    axis('equal');
    xlabel('Re$\{\underline Z\}$  in m$\Omega$');
    ylabel('Im$\{\underline Z\}$  in m$\Omega$');
    grid on; set(gca,'Ydir','reverse');
    title(' negative electrode');